==> style-o-matic-1.1.37.tgz: package/es/components/Accordion/AccordionTitle.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getCorePropTypes, getCorePropDefaults, ROLE } from "../../lib";

var AccordionTitle = (_temp = _class = function (_CoreComponent) {
  _inherits(AccordionTitle, _CoreComponent);

  function AccordionTitle() {
    _classCallCheck(this, AccordionTitle);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  AccordionTitle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        active = _getValidProps.active,
        children = _getValidProps.children,
        accordionindex = _getValidProps.accordionindex,
        props = _getValidProps.props;

    var caretClass = active ? "ui-icon-folder-open" : "ui-icon-folder";

    return React.createElement(
      Component,
      _extends({}, props, { accordionindex: accordionindex }),
      React.createElement("span", {
        className: "ui-accordion-caret " + caretClass,
        "aria-hidden": "true"
      }),
      children
    );
  };

  return AccordionTitle;
}(CoreComponent), _class.propTypes = getCorePropTypes({ accordionindex: "string" }), _class.defaultProps = getCorePropDefaults({
  renderAs: "dt",
  uirole: ROLE.TITLE
}), _temp);


export default AccordionTitle;

==> style-o-matic-1.2.0.tgz: package/es/components/Accordion/AccordionTitle.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof Accordion
 * @todo Write sub-component documentation
 * @author Steven Jackson
 */
import React from "react";
import { CoreComponent, getValidProps, setCorePropTypes, setCorePropDefaults, ROLE } from "../../lib";
/**
 * [AccordionTitle description]
 * @extends CoreComponent
 */
var AccordionTitle = (_temp = _class = function (_CoreComponent) {
  _inherits(AccordionTitle, _CoreComponent);

  function AccordionTitle() {
    _classCallCheck(this, AccordionTitle);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  AccordionTitle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        active = _getValidProps.active,
        children = _getValidProps.children,
        accordionindex = _getValidProps.accordionindex,
        props = _getValidProps.props;

    var caretClass = active ? "ui-icon-folder-open" : "ui-icon-folder";

    return React.createElement(
      Component,
      _extends({}, props, { accordionindex: accordionindex }),
      React.createElement("span", {
        className: "ui-accordion-caret " + caretClass,
        "aria-hidden": "true"
      }),
      children
    );
  };

  return AccordionTitle;
}(CoreComponent), _class.propTypes = setCorePropTypes({ accordionindex: "string" }), _class.defaultProps = setCorePropDefaults({
  renderAs: "dt",
  uirole: ROLE.TITLE,
  role: ROLE.PRESENTATION
}), _temp);


export default AccordionTitle;
